package com.qmth.boot.core.ai.client;

import com.qmth.boot.core.ai.config.LlmApiConfiguration;
import com.qmth.boot.core.ai.model.AiConstants;
import com.qmth.boot.core.ai.model.llm.*;
import com.qmth.boot.core.ai.model.llm.endpoint.ChatEndpoint;
import com.qmth.boot.core.retrofit.annotatioin.RetrofitClient;
import com.qmth.boot.core.retrofit.utils.SignatureInfo;
import retrofit2.http.*;

/**
 * 大模型应用服务接口
 */
@RetrofitClient(configuration = LlmApiConfiguration.class)
public interface LlmApiClient {

    /**
     * 构建大模型chat类型请求信息
     *
     * @param baseUrl        接口前缀地址，默认取配置文件的值（选填）
     * @param signature      使用机构AK构造Secret类型签名
     * @param type           大模型应用类型
     * @param param          提示词模版变量参数
     * @param stream         是否流式输出
     * @param enableThinking 是否启用思考模式（若开启思考模式，则默认流式输出）
     * @return
     */
    @POST(AiConstants.LLM_CHAT_ENDPOINT_PATH)
    ChatEndpoint chatEndpoint(@Header(AiConstants.BASE_URL) String baseUrl, @Tag SignatureInfo signature,
                              @Header(AiConstants.LLM_APP_TYPE) LlmAppType type,
                              @Body Object param,
                              @Query("stream") Boolean stream,
                              @Query("enableThinking") Boolean enableThinking);

    /**
     * 调用大模型chat类型请求（预设提示词模版）
     *
     * @param baseUrl   接口前缀地址，默认取配置文件的值（选填）
     * @param signature 使用机构AK构造Secret类型签名
     * @param type      大模型应用类型
     * @param param     提示词模版变量参数
     * @return
     */
    @POST(AiConstants.LLM_CHAT_TEMPLATE_PATH)
    ChatResult chatTemplate(@Header(AiConstants.BASE_URL) String baseUrl, @Tag SignatureInfo signature,
                            @Header(AiConstants.LLM_APP_TYPE) LlmAppType type,
                            @Body Object param);

    /**
     * 调用大模型chat类型请求（自定义提示词模版）
     *
     * @param baseUrl   接口前缀地址，默认取配置文件的值（选填）
     * @param signature 使用机构AK构造Secret类型签名
     * @param type      大模型应用类型
     * @param request   自定义提示词请求对象
     * @return
     */
    @Deprecated
    @POST(AiConstants.LLM_CHAT_PATH)
    ChatResult chat(@Header(AiConstants.BASE_URL) String baseUrl, @Tag SignatureInfo signature,
                    @Header(AiConstants.LLM_APP_TYPE) LlmAppType type,
                    @Body ChatRequest request);

    /**
     * 查询大模型接口余额
     *
     * @param baseUrl   接口前缀地址，默认取配置文件的值（选填）
     * @param signature 使用机构AK构造Secret类型签名
     * @param type      大模型应用类型
     * @return
     */
    @POST(AiConstants.LLM_BALANCE_PATH)
    LlmAppBalance getBalance(@Header(AiConstants.BASE_URL) String baseUrl, @Tag SignatureInfo signature,
                             @Header(AiConstants.LLM_APP_TYPE) LlmAppType type);

    /**
     * 消费大模型接口余额
     *
     * @param baseUrl   接口前缀地址，默认取配置文件的值（选填）
     * @param signature 使用机构AK构造Secret类型签名
     * @param type      大模型应用类型
     * @return
     */
    @POST(AiConstants.LLM_BALANCE_CONSUME_PATH)
    LlmAppBalance consumeBalance(@Header(AiConstants.BASE_URL) String baseUrl, @Tag SignatureInfo signature,
                                 @Header(AiConstants.LLM_APP_TYPE) LlmAppType type);

    /**
     * 大模型提示词模版获取
     *
     * @param baseUrl   接口前缀地址，默认取配置文件的值（选填）
     * @param signature 使用机构AK构造Secret类型签名
     * @param type      大模型应用类型
     * @return
     */
    @POST(AiConstants.LLM_PROMPT_TEMPLATE_PATH)
    PromptTemplate getPromptTemplate(@Header(AiConstants.BASE_URL) String baseUrl, @Tag SignatureInfo signature,
                                     @Header(AiConstants.LLM_APP_TYPE) LlmAppType type);

}
